//////////////////////////////////////////////////////////////
//                     1602_LCD.c                           // 
// Bu LCD src dosyas 2x16 HD44780 uyumlu LCDler        //
// iin yazlmtr. LCDye sadece yazma yaplaca iin    //
// R/W ucu aseye balanmaldr. LCD balants aadadr. //
//////////////////////////////////////////////////////////////
// RB0 -> LCDnin D4 ucuna
// RB1 -> LCDnin D5 ucuna
// RB2 -> LCDnin D6 ucuna
// RB3 -> LCDnin D7 ucuna
// RB4 -> LCDnin RS ucuna
// RB5 -> LCDnin E  ucuna
// R/W ucu direkt aseye balanacak

#define e   pin_b5 // LCD'nin E ucu RB5 pinine bal
#define rs  pin_b4 // LCD'nin RS ucu RB4 pinine bal

//****** LCD'ye Komut Gnderme Fonksiyonu **********
void lcd_komut(byte komut)
{   
   output_b(komut>>4);   // Komutun yksek deerli 4 bitini gnder
   output_low(rs);       // LCD komut almak iin ayarland
   delay_cycles(1);      // 1 komut saykl bekle   
   output_high(e);       // E ucu lojik-1'den lojik-0'a ekiliyor
   delay_cycles(1);      // 1 komut saykl bekle
   output_low(e);
   delay_ms(2);          // 2 msn gecikme veriliyor

   output_b(komut&0x0F); // Komutun dk deerli 4 bitini gnder
   output_low(rs);      // LCD veri almak iin ayarland  
   delay_cycles(1);      // 1 komut saykl bekle      
   output_high(e);       // E ucu lojik-1'den lojik-0'a ekiliyor
   delay_cycles(1);      // 1 komut saykl bekle
   output_low(e);
   delay_ms(2);          // 2 msn gecikme veriliyor
}

//******* LCD'ye Veri Gnderme Fonksiyonu **********
void lcd_putc(byte veri)
{ 
   output_b(veri>>4);    // Verinin yksek deerli 4 bitini gnder
   output_high(rs);      // LCD veri almak iin ayarland
   delay_cycles(1);      // 1 komut saykl bekle    
   output_high(e);       // E ucu lojik-1'den lojik-0'a ekiliyor
   delay_cycles(1);      // 1 komut saykl bekle
   output_low(e);
   delay_ms(2);          // 2 msn gecikme veriliyor

   output_b(veri&0x0F); // Verinin dk deerli 4 bitini gnder
   output_high(rs);      // LCD veri almak iin ayarland
   delay_cycles(1);      // 1 komut saykl bekle    
   output_high(e);      // E ucu lojik-1'den lojik-0'a ekiliyor
   delay_cycles(1);     // 1 komut saykl bekle
   output_low(e);
   delay_ms(2);         // 2 msn gecikme veriliyor
}

//******* LCD'de mlec Konumlandrma Fonksiyonu ********
void lcd_gotoxy(byte satir, byte sutun)
{
   if (satir==1)      // Eer satr deikeni "1" ise
      lcd_komut(0x80|(sutun-1));

   if (satir==2)      // Eer satr deikeni "2" ise
      lcd_komut(0x80|(0x40+(sutun-1)));
}

//********* LCD Balang Ayarlar Fonksiyonu ******
void lcd_init()
{
   int i=0;
   output_low(rs); // RS ucu lojik-0
   output_low(e);  // E ucu lojik-0
   delay_ms(30);   // LCD enerjlendiinde LCD'nin hazr olmas iin beklenen sre
   
   for(i=0;i<=3;i++)    // LCD'ye 3 kez 0x03 komutu gnderiliyor
   {
      lcd_komut(0x03);
      delay_ms(5);      // 5msn gecikme veriliyor
   }
   lcd_komut(0x02); // LCD'ye 4 bit iletiim komutu gnderiliyor
   lcd_komut(0x28); // 4 bit iletiim, 2 satr, 5x8 dot matris seildi
   lcd_komut(0x08); // Display Kapal
   lcd_komut(0x0C); // Display ak,imle alt izgi ve yanp snme yok
   lcd_komut(0x06); // Her veri yazldnda imle bir saa gitsin
   lcd_komut(0x01); // Display sil. mle 1.satr 1.stunda
}

